@@ -37,19 +37,16 @@ PPT_MIME_TYPES = [
 # If the MIME type is application/octet-stream, we check if it's a .docx/.xlsx file by
 # looking for expected filenames within the zip file.
 EXPECTED_DOCX_FILES = [
-    "docProps/app.xml",
     "docProps/core.xml",
     "word/document.xml",
 ]
 
 EXPECTED_XLSX_FILES = [
-    "docProps/app.xml",
     "docProps/core.xml",
     "xl/workbook.xml",
 ]
 
 EXPECTED_PPTX_FILES = [
-    "docProps/app.xml",
     "docProps/core.xml",
     "ppt/presentation.xml",
 ]
@@ -124,7 +121,7 @@ def detect_filetype(
     elif file is not None:
         extension = None
         # NOTE(robinson) - the python-magic docs recommend reading at least the first 2048 bytes
-        # Increased to 4096 because otherwise .xlsx files get detected as a zip fle
+        # Increased to 4096 because otherwise .xlsx files get detected as a zip file
         # ref: https://github.com/ahupp/python-magic#usage
         mime_type = magic.from_buffer(file.read(4096), mime=True)
     else:
@@ -156,7 +153,7 @@ def detect_filetype(
         else:
             return FileType.TXT
 
-    elif mime_type == "text/xml":
+    elif mime_type.endswith("xml"):
         if extension and extension == ".html":
             return FileType.HTML
         else:
